Module: Raylib

Extended by:
FFI::Library
Defined in:
lib/raylib.rb,
lib/raylib/version.rb,
lib/raylib/core/enums.rb,
lib/raylib/rlgl/enums.rb,
lib/raylib/core/colors.rb,
lib/raylib/core/callbacks.rb,
lib/raylib/core/functions.rb,
lib/raylib/rlgl/callbacks.rb,
lib/raylib/rlgl/functions.rb,
lib/raylib/core/structs/ray.rb,
lib/raylib/core/structs/font.rb,
lib/raylib/core/structs/mesh.rb,
lib/raylib/core/structs/wave.rb,
lib/raylib/raymath/functions.rb,
lib/raylib/core/structs/color.rb,
lib/raylib/core/structs/image.rb,
lib/raylib/core/structs/model.rb,
lib/raylib/core/structs/music.rb,
lib/raylib/core/structs/sound.rb,
lib/raylib/core/structs/matrix.rb,
lib/raylib/core/structs/shader.rb,
lib/raylib/core/structs/texture.rb,
lib/raylib/core/structs/vector2.rb,
lib/raylib/core/structs/vector3.rb,
lib/raylib/core/structs/vector4.rb,
lib/raylib/core/structs/material.rb,
lib/raylib/core/structs/bone_info.rb,
lib/raylib/core/structs/camera2_d.rb,
lib/raylib/core/structs/camera3_d.rb,
lib/raylib/core/structs/rectangle.rb,
lib/raylib/core/structs/transform.rb,
lib/raylib/raymath/structs/float3.rb,
lib/raylib/core/structs/glyph_info.rb,
lib/raylib/raymath/structs/float16.rb,
lib/raylib/core/structs/audio_stream.rb,
lib/raylib/core/structs/bounding_box.rb,
lib/raylib/core/structs/material_map.rb,
lib/raylib/core/structs/n_patch_info.rb,
lib/raylib/rlgl/structs/rl_draw_call.rb,
lib/raylib/core/structs/ray_collision.rb,
lib/raylib/core/structs/file_path_list.rb,
lib/raylib/core/structs/render_texture.rb,
lib/raylib/core/structs/vr_device_info.rb,
lib/raylib/core/structs/model_animation.rb,
lib/raylib/rlgl/structs/rl_render_batch.rb,
lib/raylib/core/structs/vr_stereo_config.rb,
lib/raylib/rlgl/structs/rl_vertex_buffer.rb

Defined Under Namespace

Classes: AudioStream, BoneInfo, BoundingBox, Camera2D, Camera3D, Color, FilePathList, Float16, Float3, Font, GlyphInfo, Image, Material, MaterialMap, Matrix, Mesh, Model, ModelAnimation, Music, NPatchInfo, Ray, RayCollision, Rectangle, RenderTexture, RlDrawCall, RlRenderBatch, RlVertexBuffer, Shader, Sound, Texture, Transform, Vector2, Vector3, Vector4, VrDeviceInfo, VrStereoConfig, Wave

Constant Summary collapse

VERSION =
'4.5.0.alpha1'
FLAG_VSYNC_HINT =

Set to try enabling V-Sync on GPU

64
FLAG_FULLSCREEN_MODE =

Set to run program in fullscreen

2
FLAG_WINDOW_RESIZABLE =

Set to allow resizable window

4
FLAG_WINDOW_UNDECORATED =

Set to disable window decoration (frame and buttons)

8
FLAG_WINDOW_HIDDEN =

Set to hide window

128
FLAG_WINDOW_MINIMIZED =

Set to minimize window (iconify)

512
FLAG_WINDOW_MAXIMIZED =

Set to maximize window (expanded to monitor)

1024
FLAG_WINDOW_UNFOCUSED =

Set to window non focused

2048
FLAG_WINDOW_TOPMOST =

Set to window always on top

4096
FLAG_WINDOW_ALWAYS_RUN =

Set to allow windows running while minimized

256
FLAG_WINDOW_TRANSPARENT =

Set to allow transparent framebuffer

16
FLAG_WINDOW_HIGHDPI =

Set to support HighDPI

8192
FLAG_WINDOW_MOUSE_PASSTHROUGH =

Set to support mouse passthrough, only supported when FLAG_WINDOW_UNDECORATED

16384
FLAG_MSAA_4X_HINT =

Set to try enabling MSAA 4X

32
FLAG_INTERLACED_HINT =

Set to try enabling interlaced video format (for V3D)

65536
LOG_ALL =

Display all logs

0
LOG_TRACE =

Trace logging, intended for internal use only

1
LOG_DEBUG =

Debug logging, used for internal debugging, it should be disabled on release builds

2
LOG_INFO =

Info logging, used for program execution info

3
LOG_WARNING =

Warning logging, used on recoverable failures

4
LOG_ERROR =

Error logging, used on unrecoverable failures

5
LOG_FATAL =

Fatal logging, used to abort program: exit(EXIT_FAILURE)

6
LOG_NONE =

Disable logging

7
KEY_NULL =

Key: NULL, used for no key pressed

0
KEY_APOSTROPHE =

Key: ‘

39
KEY_COMMA =

Key: ,

44
KEY_MINUS =

Key: -

45
KEY_PERIOD =

Key: .

46
KEY_SLASH =

Key: /

47
KEY_ZERO =

Key: 0

48
KEY_ONE =

Key: 1

49
KEY_TWO =

Key: 2

50
KEY_THREE =

Key: 3

51
KEY_FOUR =

Key: 4

52
KEY_FIVE =

Key: 5

53
KEY_SIX =

Key: 6

54
KEY_SEVEN =

Key: 7

55
KEY_EIGHT =

Key: 8

56
KEY_NINE =

Key: 9

57
KEY_SEMICOLON =

Key: ;

59
KEY_EQUAL =

Key: =

61
KEY_A =

Key: A | a

65
KEY_B =

Key: B | b

66
KEY_C =

Key: C | c

67
KEY_D =

Key: D | d

68
KEY_E =

Key: E | e

69
KEY_F =

Key: F | f

70
KEY_G =

Key: G | g

71
KEY_H =

Key: H | h

72
KEY_I =

Key: I | i

73
KEY_J =

Key: J | j

74
KEY_K =

Key: K | k

75
KEY_L =

Key: L | l

76
KEY_M =

Key: M | m

77
KEY_N =

Key: N | n

78
KEY_O =

Key: O | o

79
KEY_P =

Key: P | p

80
KEY_Q =

Key: Q | q

81
KEY_R =

Key: R | r

82
KEY_S =

Key: S | s

83
KEY_T =

Key: T | t

84
KEY_U =

Key: U | u

85
KEY_V =

Key: V | v

86
KEY_W =

Key: W | w

87
KEY_X =

Key: X | x

88
KEY_Y =

Key: Y | y

89
KEY_Z =

Key: Z | z

90
KEY_LEFT_BRACKET =

Key: [

91
KEY_BACKSLASH =

Key: ‘'

92
KEY_RIGHT_BRACKET =

Key: ]

93
KEY_GRAVE =

Key: ‘

96
KEY_SPACE =

Key: Space

32
KEY_ESCAPE =

Key: Esc

256
KEY_ENTER =

Key: Enter

257
KEY_TAB =

Key: Tab

258
KEY_BACKSPACE =

Key: Backspace

259
KEY_INSERT =

Key: Ins

260
KEY_DELETE =

Key: Del

261
KEY_RIGHT =

Key: Cursor right

262
KEY_LEFT =

Key: Cursor left

263
KEY_DOWN =

Key: Cursor down

264
KEY_UP =

Key: Cursor up

265
KEY_PAGE_UP =

Key: Page up

266
KEY_PAGE_DOWN =

Key: Page down

267
KEY_HOME =

Key: Home

268
KEY_END =

Key: End

269
KEY_CAPS_LOCK =

Key: Caps lock

280
KEY_SCROLL_LOCK =

Key: Scroll down

281
KEY_NUM_LOCK =

Key: Num lock

282
KEY_PRINT_SCREEN =

Key: Print screen

283
KEY_PAUSE =

Key: Pause

284
KEY_F1 =

Key: F1

290
KEY_F2 =

Key: F2

291
KEY_F3 =

Key: F3

292
KEY_F4 =

Key: F4

293
KEY_F5 =

Key: F5

294
KEY_F6 =

Key: F6

295
KEY_F7 =

Key: F7

296
KEY_F8 =

Key: F8

297
KEY_F9 =

Key: F9

298
KEY_F10 =

Key: F10

299
KEY_F11 =

Key: F11

300
KEY_F12 =

Key: F12

301
KEY_LEFT_SHIFT =

Key: Shift left

340
KEY_LEFT_CONTROL =

Key: Control left

341
KEY_LEFT_ALT =

Key: Alt left

342
KEY_LEFT_SUPER =

Key: Super left

343
KEY_RIGHT_SHIFT =

Key: Shift right

344
KEY_RIGHT_CONTROL =

Key: Control right

345
KEY_RIGHT_ALT =

Key: Alt right

346
KEY_RIGHT_SUPER =

Key: Super right

347
KEY_KB_MENU =

Key: KB menu

348
KEY_KP_0 =

Key: Keypad 0

320
KEY_KP_1 =

Key: Keypad 1

321
KEY_KP_2 =

Key: Keypad 2

322
KEY_KP_3 =

Key: Keypad 3

323
KEY_KP_4 =

Key: Keypad 4

324
KEY_KP_5 =

Key: Keypad 5

325
KEY_KP_6 =

Key: Keypad 6

326
KEY_KP_7 =

Key: Keypad 7

327
KEY_KP_8 =

Key: Keypad 8

328
KEY_KP_9 =

Key: Keypad 9

329
KEY_KP_DECIMAL =

Key: Keypad .

330
KEY_KP_DIVIDE =

Key: Keypad /

331
KEY_KP_MULTIPLY =

Key: Keypad *

332
KEY_KP_SUBTRACT =

Key: Keypad -

333
KEY_KP_ADD =

Key: Keypad +

334
KEY_KP_ENTER =

Key: Keypad Enter

335
KEY_KP_EQUAL =

Key: Keypad =

336
KEY_BACK =

Key: Android back button

4
KEY_MENU =

Key: Android menu button

82
KEY_VOLUME_UP =

Key: Android volume up button

24
KEY_VOLUME_DOWN =

Key: Android volume down button

25
MOUSE_BUTTON_LEFT =

Mouse button left

0
MOUSE_BUTTON_RIGHT =

Mouse button right

1
MOUSE_BUTTON_MIDDLE =

Mouse button middle (pressed wheel)

2
MOUSE_BUTTON_SIDE =

Mouse button side (advanced mouse device)

3
MOUSE_BUTTON_EXTRA =

Mouse button extra (advanced mouse device)

4
MOUSE_BUTTON_FORWARD =

Mouse button forward (advanced mouse device)

5
MOUSE_BUTTON_BACK =

Mouse button back (advanced mouse device)

6
MOUSE_CURSOR_DEFAULT =

Default pointer shape

0
MOUSE_CURSOR_ARROW =

Arrow shape

1
MOUSE_CURSOR_IBEAM =

Text writing cursor shape

2
MOUSE_CURSOR_CROSSHAIR =

Cross shape

3
MOUSE_CURSOR_POINTING_HAND =

Pointing hand cursor

4
MOUSE_CURSOR_RESIZE_EW =

Horizontal resize/move arrow shape

5
MOUSE_CURSOR_RESIZE_NS =

Vertical resize/move arrow shape

6
MOUSE_CURSOR_RESIZE_NWSE =

Top-left to bottom-right diagonal resize/move arrow shape

7
MOUSE_CURSOR_RESIZE_NESW =

The top-right to bottom-left diagonal resize/move arrow shape

8
MOUSE_CURSOR_RESIZE_ALL =

The omnidirectional resize/move cursor shape

9
MOUSE_CURSOR_NOT_ALLOWED =

The operation-not-allowed shape

10
GAMEPAD_BUTTON_UNKNOWN =

Unknown button, just for error checking

0
GAMEPAD_BUTTON_LEFT_FACE_UP =

Gamepad left DPAD up button

1
GAMEPAD_BUTTON_LEFT_FACE_RIGHT =

Gamepad left DPAD right button

2
GAMEPAD_BUTTON_LEFT_FACE_DOWN =

Gamepad left DPAD down button

3
GAMEPAD_BUTTON_LEFT_FACE_LEFT =

Gamepad left DPAD left button

4
GAMEPAD_BUTTON_RIGHT_FACE_UP =

Gamepad right button up (i.e. PS3: Triangle, Xbox: Y)

5
GAMEPAD_BUTTON_RIGHT_FACE_RIGHT =

Gamepad right button right (i.e. PS3: Square, Xbox: X)

6
GAMEPAD_BUTTON_RIGHT_FACE_DOWN =

Gamepad right button down (i.e. PS3: Cross, Xbox: A)

7
GAMEPAD_BUTTON_RIGHT_FACE_LEFT =

Gamepad right button left (i.e. PS3: Circle, Xbox: B)

8
GAMEPAD_BUTTON_LEFT_TRIGGER_1 =

Gamepad top/back trigger left (first), it could be a trailing button

9
GAMEPAD_BUTTON_LEFT_TRIGGER_2 =

Gamepad top/back trigger left (second), it could be a trailing button

10
GAMEPAD_BUTTON_RIGHT_TRIGGER_1 =

Gamepad top/back trigger right (one), it could be a trailing button

11
GAMEPAD_BUTTON_RIGHT_TRIGGER_2 =

Gamepad top/back trigger right (second), it could be a trailing button

12
GAMEPAD_BUTTON_MIDDLE_LEFT =

Gamepad center buttons, left one (i.e. PS3: Select)

13
GAMEPAD_BUTTON_MIDDLE =

Gamepad center buttons, middle one (i.e. PS3: PS, Xbox: XBOX)

14
GAMEPAD_BUTTON_MIDDLE_RIGHT =

Gamepad center buttons, right one (i.e. PS3: Start)

15
GAMEPAD_BUTTON_LEFT_THUMB =

Gamepad joystick pressed button left

16
GAMEPAD_BUTTON_RIGHT_THUMB =

Gamepad joystick pressed button right

17
GAMEPAD_AXIS_LEFT_X =

Gamepad left stick X axis

0
GAMEPAD_AXIS_LEFT_Y =

Gamepad left stick Y axis

1
GAMEPAD_AXIS_RIGHT_X =

Gamepad right stick X axis

2
GAMEPAD_AXIS_RIGHT_Y =

Gamepad right stick Y axis

3
GAMEPAD_AXIS_LEFT_TRIGGER =

Gamepad back trigger left, pressure level: [1..-1]

4
GAMEPAD_AXIS_RIGHT_TRIGGER =

Gamepad back trigger right, pressure level: [1..-1]

5
MATERIAL_MAP_ALBEDO =

Albedo material (same as: MATERIAL_MAP_DIFFUSE)

0
MATERIAL_MAP_METALNESS =

Metalness material (same as: MATERIAL_MAP_SPECULAR)

1
MATERIAL_MAP_NORMAL =

Normal material

2
MATERIAL_MAP_ROUGHNESS =

Roughness material

3
MATERIAL_MAP_OCCLUSION =

Ambient occlusion material

4
MATERIAL_MAP_EMISSION =

Emission material

5
MATERIAL_MAP_HEIGHT =

Heightmap material

6
MATERIAL_MAP_CUBEMAP =

Cubemap material (NOTE: Uses GL_TEXTURE_CUBE_MAP)

7
MATERIAL_MAP_IRRADIANCE =

Irradiance material (NOTE: Uses GL_TEXTURE_CUBE_MAP)

8
MATERIAL_MAP_PREFILTER =

Prefilter material (NOTE: Uses GL_TEXTURE_CUBE_MAP)

9
MATERIAL_MAP_BRDF =

Brdf material

10
SHADER_LOC_VERTEX_POSITION =

Shader location: vertex attribute: position

0
SHADER_LOC_VERTEX_TEXCOORD01 =

Shader location: vertex attribute: texcoord01

1
SHADER_LOC_VERTEX_TEXCOORD02 =

Shader location: vertex attribute: texcoord02

2
SHADER_LOC_VERTEX_NORMAL =

Shader location: vertex attribute: normal

3
SHADER_LOC_VERTEX_TANGENT =

Shader location: vertex attribute: tangent

4
SHADER_LOC_VERTEX_COLOR =

Shader location: vertex attribute: color

5
SHADER_LOC_MATRIX_MVP =

Shader location: matrix uniform: model-view-projection

6
SHADER_LOC_MATRIX_VIEW =

Shader location: matrix uniform: view (camera transform)

7
SHADER_LOC_MATRIX_PROJECTION =

Shader location: matrix uniform: projection

8
SHADER_LOC_MATRIX_MODEL =

Shader location: matrix uniform: model (transform)

9
SHADER_LOC_MATRIX_NORMAL =

Shader location: matrix uniform: normal

10
SHADER_LOC_VECTOR_VIEW =

Shader location: vector uniform: view

11
SHADER_LOC_COLOR_DIFFUSE =

Shader location: vector uniform: diffuse color

12
SHADER_LOC_COLOR_SPECULAR =

Shader location: vector uniform: specular color

13
SHADER_LOC_COLOR_AMBIENT =

Shader location: vector uniform: ambient color

14
SHADER_LOC_MAP_ALBEDO =

Shader location: sampler2d texture: albedo (same as: SHADER_LOC_MAP_DIFFUSE)

15
SHADER_LOC_MAP_METALNESS =

Shader location: sampler2d texture: metalness (same as: SHADER_LOC_MAP_SPECULAR)

16
SHADER_LOC_MAP_NORMAL =

Shader location: sampler2d texture: normal

17
SHADER_LOC_MAP_ROUGHNESS =

Shader location: sampler2d texture: roughness

18
SHADER_LOC_MAP_OCCLUSION =

Shader location: sampler2d texture: occlusion

19
SHADER_LOC_MAP_EMISSION =

Shader location: sampler2d texture: emission

20
SHADER_LOC_MAP_HEIGHT =

Shader location: sampler2d texture: height

21
SHADER_LOC_MAP_CUBEMAP =

Shader location: samplerCube texture: cubemap

22
SHADER_LOC_MAP_IRRADIANCE =

Shader location: samplerCube texture: irradiance

23
SHADER_LOC_MAP_PREFILTER =

Shader location: samplerCube texture: prefilter

24
SHADER_LOC_MAP_BRDF =

Shader location: sampler2d texture: brdf

25
SHADER_UNIFORM_FLOAT =

Shader uniform type: float

0
SHADER_UNIFORM_VEC2 =

Shader uniform type: vec2 (2 float)

1
SHADER_UNIFORM_VEC3 =

Shader uniform type: vec3 (3 float)

2
SHADER_UNIFORM_VEC4 =

Shader uniform type: vec4 (4 float)

3
SHADER_UNIFORM_INT =

Shader uniform type: int

4
SHADER_UNIFORM_IVEC2 =

Shader uniform type: ivec2 (2 int)

5
SHADER_UNIFORM_IVEC3 =

Shader uniform type: ivec3 (3 int)

6
SHADER_UNIFORM_IVEC4 =

Shader uniform type: ivec4 (4 int)

7
SHADER_UNIFORM_SAMPLER2D =

Shader uniform type: sampler2d

8
SHADER_ATTRIB_FLOAT =

Shader attribute type: float

0
SHADER_ATTRIB_VEC2 =

Shader attribute type: vec2 (2 float)

1
SHADER_ATTRIB_VEC3 =

Shader attribute type: vec3 (3 float)

2
SHADER_ATTRIB_VEC4 =

Shader attribute type: vec4 (4 float)

3
PIXELFORMAT_UNCOMPRESSED_GRAYSCALE =

8 bit per pixel (no alpha)

1
PIXELFORMAT_UNCOMPRESSED_GRAY_ALPHA =

8*2 bpp (2 channels)

2
PIXELFORMAT_UNCOMPRESSED_R5G6B5 =

16 bpp

3
PIXELFORMAT_UNCOMPRESSED_R8G8B8 =

24 bpp

4
PIXELFORMAT_UNCOMPRESSED_R5G5B5A1 =

16 bpp (1 bit alpha)

5
PIXELFORMAT_UNCOMPRESSED_R4G4B4A4 =

16 bpp (4 bit alpha)

6
PIXELFORMAT_UNCOMPRESSED_R8G8B8A8 =

32 bpp

7
PIXELFORMAT_UNCOMPRESSED_R32 =

32 bpp (1 channel - float)

8
PIXELFORMAT_UNCOMPRESSED_R32G32B32 =

32*3 bpp (3 channels - float)

9
PIXELFORMAT_UNCOMPRESSED_R32G32B32A32 =

32*4 bpp (4 channels - float)

10
PIXELFORMAT_COMPRESSED_DXT1_RGB =

4 bpp (no alpha)

11
PIXELFORMAT_COMPRESSED_DXT1_RGBA =

4 bpp (1 bit alpha)

12
PIXELFORMAT_COMPRESSED_DXT3_RGBA =

8 bpp

13
PIXELFORMAT_COMPRESSED_DXT5_RGBA =

8 bpp

14
PIXELFORMAT_COMPRESSED_ETC1_RGB =

4 bpp

15
PIXELFORMAT_COMPRESSED_ETC2_RGB =

4 bpp

16
PIXELFORMAT_COMPRESSED_ETC2_EAC_RGBA =

8 bpp

17
PIXELFORMAT_COMPRESSED_PVRT_RGB =

4 bpp

18
PIXELFORMAT_COMPRESSED_PVRT_RGBA =

4 bpp

19
PIXELFORMAT_COMPRESSED_ASTC_4x4_RGBA =

8 bpp

20
PIXELFORMAT_COMPRESSED_ASTC_8x8_RGBA =

2 bpp

21
TEXTURE_FILTER_POINT =

No filter, just pixel approximation

0
TEXTURE_FILTER_BILINEAR =

Linear filtering

1
TEXTURE_FILTER_TRILINEAR =

Trilinear filtering (linear with mipmaps)

2
TEXTURE_FILTER_ANISOTROPIC_4X =

Anisotropic filtering 4x

3
TEXTURE_FILTER_ANISOTROPIC_8X =

Anisotropic filtering 8x

4
TEXTURE_FILTER_ANISOTROPIC_16X =

Anisotropic filtering 16x

5
TEXTURE_WRAP_REPEAT =

Repeats texture in tiled mode

0
TEXTURE_WRAP_CLAMP =

Clamps texture to edge pixel in tiled mode

1
TEXTURE_WRAP_MIRROR_REPEAT =

Mirrors and repeats the texture in tiled mode

2
TEXTURE_WRAP_MIRROR_CLAMP =

Mirrors and clamps to border the texture in tiled mode

3
CUBEMAP_LAYOUT_AUTO_DETECT =

Automatically detect layout type

0
CUBEMAP_LAYOUT_LINE_VERTICAL =

Layout is defined by a vertical line with faces

1
CUBEMAP_LAYOUT_LINE_HORIZONTAL =

Layout is defined by a horizontal line with faces

2
CUBEMAP_LAYOUT_CROSS_THREE_BY_FOUR =

Layout is defined by a 3x4 cross with cubemap faces

3
CUBEMAP_LAYOUT_CROSS_FOUR_BY_THREE =

Layout is defined by a 4x3 cross with cubemap faces

4
CUBEMAP_LAYOUT_PANORAMA =

Layout is defined by a panorama image (equirrectangular map)

5
FONT_DEFAULT =

Default font generation, anti-aliased

0
FONT_BITMAP =

Bitmap font generation, no anti-aliasing

1
FONT_SDF =

SDF font generation, requires external shader

2
BLEND_ALPHA =

Blend textures considering alpha (default)

0
BLEND_ADDITIVE =

Blend textures adding colors

1
BLEND_MULTIPLIED =

Blend textures multiplying colors

2
BLEND_ADD_COLORS =

Blend textures adding colors (alternative)

3
BLEND_SUBTRACT_COLORS =

Blend textures subtracting colors (alternative)

4
BLEND_ALPHA_PREMULTIPLY =

Blend premultiplied textures considering alpha

5
BLEND_CUSTOM =

Blend textures using custom src/dst factors (use rlSetBlendFactors())

6
BLEND_CUSTOM_SEPARATE =

Blend textures using custom rgb/alpha separate src/dst factors (use rlSetBlendFactorsSeparate())

7
GESTURE_NONE =

No gesture

0
GESTURE_TAP =

Tap gesture

1
GESTURE_DOUBLETAP =

Double tap gesture

2
GESTURE_HOLD =

Hold gesture

4
GESTURE_DRAG =

Drag gesture

8
GESTURE_SWIPE_RIGHT =

Swipe right gesture

16
GESTURE_SWIPE_LEFT =

Swipe left gesture

32
GESTURE_SWIPE_UP =

Swipe up gesture

64
GESTURE_SWIPE_DOWN =

Swipe down gesture

128
GESTURE_PINCH_IN =

Pinch in gesture

256
GESTURE_PINCH_OUT =

Pinch out gesture

512
CAMERA_CUSTOM =

Custom camera

0
CAMERA_FREE =

Free camera

1
CAMERA_ORBITAL =

Orbital camera

2
CAMERA_FIRST_PERSON =

First person camera

3
CAMERA_THIRD_PERSON =

Third person camera

4
CAMERA_PERSPECTIVE =

Perspective projection

0
CAMERA_ORTHOGRAPHIC =

Orthographic projection

1
NPATCH_NINE_PATCH =

Npatch layout: 3x3 tiles

0
NPATCH_THREE_PATCH_VERTICAL =

Npatch layout: 1x3 tiles

1
NPATCH_THREE_PATCH_HORIZONTAL =

Npatch layout: 3x1 tiles

2
RL_OPENGL_11 =

OpenGL 1.1

1
RL_OPENGL_21 =

OpenGL 2.1 (GLSL 120)

2
RL_OPENGL_33 =

OpenGL 3.3 (GLSL 330)

3
RL_OPENGL_43 =

OpenGL 4.3 (using GLSL 330)

4
RL_OPENGL_ES_20 =

OpenGL ES 2.0 (GLSL 100)

5
RL_LOG_ALL =

Display all logs

0
RL_LOG_TRACE =

Trace logging, intended for internal use only

1
RL_LOG_DEBUG =

Debug logging, used for internal debugging, it should be disabled on release builds

2
RL_LOG_INFO =

Info logging, used for program execution info

3
RL_LOG_WARNING =

Warning logging, used on recoverable failures

4
RL_LOG_ERROR =

Error logging, used on unrecoverable failures

5
RL_LOG_FATAL =

Fatal logging, used to abort program: exit(EXIT_FAILURE)

6
RL_LOG_NONE =

Disable logging

7
RL_PIXELFORMAT_UNCOMPRESSED_GRAYSCALE =

8 bit per pixel (no alpha)

1
RL_PIXELFORMAT_UNCOMPRESSED_GRAY_ALPHA =

8*2 bpp (2 channels)

2
RL_PIXELFORMAT_UNCOMPRESSED_R5G6B5 =

16 bpp

3
RL_PIXELFORMAT_UNCOMPRESSED_R8G8B8 =

24 bpp

4
RL_PIXELFORMAT_UNCOMPRESSED_R5G5B5A1 =

16 bpp (1 bit alpha)

5
RL_PIXELFORMAT_UNCOMPRESSED_R4G4B4A4 =

16 bpp (4 bit alpha)

6
RL_PIXELFORMAT_UNCOMPRESSED_R8G8B8A8 =

32 bpp

7
RL_PIXELFORMAT_UNCOMPRESSED_R32 =

32 bpp (1 channel - float)

8
RL_PIXELFORMAT_UNCOMPRESSED_R32G32B32 =

32*3 bpp (3 channels - float)

9
RL_PIXELFORMAT_UNCOMPRESSED_R32G32B32A32 =

32*4 bpp (4 channels - float)

10
RL_PIXELFORMAT_COMPRESSED_DXT1_RGB =

4 bpp (no alpha)

11
RL_PIXELFORMAT_COMPRESSED_DXT1_RGBA =

4 bpp (1 bit alpha)

12
RL_PIXELFORMAT_COMPRESSED_DXT3_RGBA =

8 bpp

13
RL_PIXELFORMAT_COMPRESSED_DXT5_RGBA =

8 bpp

14
RL_PIXELFORMAT_COMPRESSED_ETC1_RGB =

4 bpp

15
RL_PIXELFORMAT_COMPRESSED_ETC2_RGB =

4 bpp

16
RL_PIXELFORMAT_COMPRESSED_ETC2_EAC_RGBA =

8 bpp

17
RL_PIXELFORMAT_COMPRESSED_PVRT_RGB =

4 bpp

18
RL_PIXELFORMAT_COMPRESSED_PVRT_RGBA =

4 bpp

19
RL_PIXELFORMAT_COMPRESSED_ASTC_4x4_RGBA =

8 bpp

20
RL_PIXELFORMAT_COMPRESSED_ASTC_8x8_RGBA =

2 bpp

21
RL_TEXTURE_FILTER_POINT =

No filter, just pixel approximation

0
RL_TEXTURE_FILTER_BILINEAR =

Linear filtering

1
RL_TEXTURE_FILTER_TRILINEAR =

Trilinear filtering (linear with mipmaps)

2
RL_TEXTURE_FILTER_ANISOTROPIC_4X =

Anisotropic filtering 4x

3
RL_TEXTURE_FILTER_ANISOTROPIC_8X =

Anisotropic filtering 8x

4
RL_TEXTURE_FILTER_ANISOTROPIC_16X =

Anisotropic filtering 16x

5
RL_BLEND_ALPHA =

Blend textures considering alpha (default)

0
RL_BLEND_ADDITIVE =

Blend textures adding colors

1
RL_BLEND_MULTIPLIED =

Blend textures multiplying colors

2
RL_BLEND_ADD_COLORS =

Blend textures adding colors (alternative)

3
RL_BLEND_SUBTRACT_COLORS =

Blend textures subtracting colors (alternative)

4
RL_BLEND_ALPHA_PREMULTIPLY =

Blend premultiplied textures considering alpha

5
RL_BLEND_CUSTOM =

Blend textures using custom src/dst factors (use rlSetBlendFactors())

6
RL_BLEND_CUSTOM_SEPARATE =

Blend textures using custom src/dst factors (use rlSetBlendFactorsSeparate())

7
RL_SHADER_LOC_VERTEX_POSITION =

Shader location: vertex attribute: position

0
RL_SHADER_LOC_VERTEX_TEXCOORD01 =

Shader location: vertex attribute: texcoord01

1
RL_SHADER_LOC_VERTEX_TEXCOORD02 =

Shader location: vertex attribute: texcoord02

2
RL_SHADER_LOC_VERTEX_NORMAL =

Shader location: vertex attribute: normal

3
RL_SHADER_LOC_VERTEX_TANGENT =

Shader location: vertex attribute: tangent

4
RL_SHADER_LOC_VERTEX_COLOR =

Shader location: vertex attribute: color

5
RL_SHADER_LOC_MATRIX_MVP =

Shader location: matrix uniform: model-view-projection

6
RL_SHADER_LOC_MATRIX_VIEW =

Shader location: matrix uniform: view (camera transform)

7
RL_SHADER_LOC_MATRIX_PROJECTION =

Shader location: matrix uniform: projection

8
RL_SHADER_LOC_MATRIX_MODEL =

Shader location: matrix uniform: model (transform)

9
RL_SHADER_LOC_MATRIX_NORMAL =

Shader location: matrix uniform: normal

10
RL_SHADER_LOC_VECTOR_VIEW =

Shader location: vector uniform: view

11
RL_SHADER_LOC_COLOR_DIFFUSE =

Shader location: vector uniform: diffuse color

12
RL_SHADER_LOC_COLOR_SPECULAR =

Shader location: vector uniform: specular color

13
RL_SHADER_LOC_COLOR_AMBIENT =

Shader location: vector uniform: ambient color

14
RL_SHADER_LOC_MAP_ALBEDO =

Shader location: sampler2d texture: albedo (same as: RL_SHADER_LOC_MAP_DIFFUSE)

15
RL_SHADER_LOC_MAP_METALNESS =

Shader location: sampler2d texture: metalness (same as: RL_SHADER_LOC_MAP_SPECULAR)

16
RL_SHADER_LOC_MAP_NORMAL =

Shader location: sampler2d texture: normal

17
RL_SHADER_LOC_MAP_ROUGHNESS =

Shader location: sampler2d texture: roughness

18
RL_SHADER_LOC_MAP_OCCLUSION =

Shader location: sampler2d texture: occlusion

19
RL_SHADER_LOC_MAP_EMISSION =

Shader location: sampler2d texture: emission

20
RL_SHADER_LOC_MAP_HEIGHT =

Shader location: sampler2d texture: height

21
RL_SHADER_LOC_MAP_CUBEMAP =

Shader location: samplerCube texture: cubemap

22
RL_SHADER_LOC_MAP_IRRADIANCE =

Shader location: samplerCube texture: irradiance

23
RL_SHADER_LOC_MAP_PREFILTER =

Shader location: samplerCube texture: prefilter

24
RL_SHADER_LOC_MAP_BRDF =

Shader location: sampler2d texture: brdf

25
RL_SHADER_UNIFORM_FLOAT =

Shader uniform type: float

0
RL_SHADER_UNIFORM_VEC2 =

Shader uniform type: vec2 (2 float)

1
RL_SHADER_UNIFORM_VEC3 =

Shader uniform type: vec3 (3 float)

2
RL_SHADER_UNIFORM_VEC4 =

Shader uniform type: vec4 (4 float)

3
RL_SHADER_UNIFORM_INT =

Shader uniform type: int

4
RL_SHADER_UNIFORM_IVEC2 =

Shader uniform type: ivec2 (2 int)

5
RL_SHADER_UNIFORM_IVEC3 =

Shader uniform type: ivec3 (3 int)

6
RL_SHADER_UNIFORM_IVEC4 =

Shader uniform type: ivec4 (4 int)

7
RL_SHADER_UNIFORM_SAMPLER2D =

Shader uniform type: sampler2d

8
RL_SHADER_ATTRIB_FLOAT =

Shader attribute type: float

0
RL_SHADER_ATTRIB_VEC2 =

Shader attribute type: vec2 (2 float)

1
RL_SHADER_ATTRIB_VEC3 =

Shader attribute type: vec3 (3 float)

2
RL_SHADER_ATTRIB_VEC4 =

Shader attribute type: vec4 (4 float)

3
RL_ATTACHMENT_COLOR_CHANNEL0 =

Framebuffer attachment type: color 0

0
RL_ATTACHMENT_COLOR_CHANNEL1 =

Framebuffer attachment type: color 1

1
RL_ATTACHMENT_COLOR_CHANNEL2 =

Framebuffer attachment type: color 2

2
RL_ATTACHMENT_COLOR_CHANNEL3 =

Framebuffer attachment type: color 3

3
RL_ATTACHMENT_COLOR_CHANNEL4 =

Framebuffer attachment type: color 4

4
RL_ATTACHMENT_COLOR_CHANNEL5 =

Framebuffer attachment type: color 5

5
RL_ATTACHMENT_COLOR_CHANNEL6 =

Framebuffer attachment type: color 6

6
RL_ATTACHMENT_COLOR_CHANNEL7 =

Framebuffer attachment type: color 7

7
RL_ATTACHMENT_DEPTH =

Framebuffer attachment type: depth

100
RL_ATTACHMENT_STENCIL =

Framebuffer attachment type: stencil

200
RL_ATTACHMENT_CUBEMAP_POSITIVE_X =

Framebuffer texture attachment type: cubemap, +X side

0
RL_ATTACHMENT_CUBEMAP_NEGATIVE_X =

Framebuffer texture attachment type: cubemap, -X side

1
RL_ATTACHMENT_CUBEMAP_POSITIVE_Y =

Framebuffer texture attachment type: cubemap, +Y side

2
RL_ATTACHMENT_CUBEMAP_NEGATIVE_Y =

Framebuffer texture attachment type: cubemap, -Y side

3
RL_ATTACHMENT_CUBEMAP_POSITIVE_Z =

Framebuffer texture attachment type: cubemap, +Z side

4
RL_ATTACHMENT_CUBEMAP_NEGATIVE_Z =

Framebuffer texture attachment type: cubemap, -Z side

5
RL_ATTACHMENT_TEXTURE2D =

Framebuffer texture attachment type: texture2d

100
RL_ATTACHMENT_RENDERBUFFER =

Framebuffer texture attachment type: renderbuffer

200
RL_CULL_FACE_FRONT =

TODO

0
RL_CULL_FACE_BACK =

TODO

1
LIGHTGRAY =

Some Basic Colors NOTE: Custom raylib color palette for amazing visuals on WHITE background

Color.create(200, 200, 200, 255)
GRAY =

Gray

Color.create(130, 130, 130, 255)
DARKGRAY =

Dark Gray

Color.create(80, 80, 80, 255)
YELLOW =

Yellow

Color.create(253, 249, 0, 255)
GOLD =

Gold

Color.create(255, 203, 0, 255)
ORANGE =

Orange

Color.create(255, 161, 0, 255)
PINK =

Pink

Color.create(255, 109, 194, 255)
RED =

Red

Color.create(230, 41, 55, 255)
MAROON =

Maroon

Color.create(190, 33, 55, 255)
GREEN =

Green

Color.create(0, 228, 48, 255)
LIME =

Lime

Color.create(0, 158, 47, 255)
DARKGREEN =

Dark Green

Color.create(0, 117, 44, 255)
SKYBLUE =

Sky Blue

Color.create(102, 191, 255, 255)
BLUE =

Blue

Color.create(0, 121, 241, 255)
DARKBLUE =

Dark Blue

Color.create(0, 82, 172, 255)
PURPLE =

Purple

Color.create(200, 122, 255, 255)
VIOLET =

Violet

Color.create(135, 60, 190, 255)
DARKPURPLE =

Dark Purple

Color.create(112, 31, 126, 255)
BEIGE =

Beige

Color.create(211, 176, 131, 255)
BROWN =

Brown

Color.create(127, 106, 79, 255)
DARKBROWN =

Dark Brown

Color.create(76, 63, 47, 255)
WHITE =

White

Color.create(255, 255, 255, 255)
BLACK =

Black

Color.create(0, 0, 0, 255)
BLANK =

Blank (Transparent)

Color.create(0, 0, 0, 0)
MAGENTA =

Magenta

Color.create(255, 0, 255, 255)
RAYWHITE =

My own White (raylib logo)

Color.create(245, 245, 245, 255)
Texture2D =

Texture2D, same as Texture

Texture
TextureCubemap =

TextureCubemap, same as Texture

Texture
Quaternion =

Quaternion, 4 components (Vector4 alias)

Vector4
Camera =

Camera type fallback, defaults to Camera3D

Camera3D
RenderTexture2D =

RenderTexture2D, same as RenderTexture

RenderTexture